@@ -5,8 +5,7 @@ mod types;
 pub mod vm;
 
 pub use client::{Client, RestartError, RevertSnapshotError};
-pub use jsonrpsee_ws_client::Error as RpcError;
-pub use jsonrpsee_ws_client::JsonValue;
+pub use jsonrpsee_types::{Error as RpcError, JsonValue};
 pub use object_type::ObjectType;
 pub use types::{Snapshot, SnapshotId, Subscription, VmId};
 pub use vm::Vm;
